@@ -5,7 +5,6 @@ package lint
 
 import (
 	"context"
-	"errors"
 
 	"github.com/derailed/popeye/internal"
 	"github.com/derailed/popeye/internal/cache"
@@ -41,7 +40,7 @@ func (s *CronJob) Lint(ctx context.Context) error {
 		cj := o.(*batchv1.CronJob)
 		fqn := client.FQN(cj.Namespace, cj.Name)
 		s.InitOutcome(fqn)
-		ctx = internal.WithSpec(ctx, specFor(fqn, cj))
+		ctx = internal.WithSpec(ctx, SpecFor(fqn, cj))
 		s.checkCronJob(ctx, fqn, cj)
 		s.checkContainers(ctx, fqn, cj.Spec.JobTemplate.Spec.Template.Spec)
 		s.checkUtilization(ctx, over, fqn)
@@ -91,7 +90,7 @@ func (s *CronJob) checkUtilization(ctx context.Context, over bool, fqn string) {
 		s.AddErr(ctx, err)
 		return
 	}
-	mx := jobResourceUsage(ctx, s.db, s, jj)
+	mx := jobResourceUsage(s.db, jj)
 	if mx.RequestCPU.IsZero() && mx.RequestMEM.IsZero() {
 		return
 	}
@@ -105,13 +104,14 @@ func checkEvents(ctx context.Context, ii *issues.Collector, r internal.R, kind,
 	ee, err := dao.EventsFor(ctx, internal.Glossary[r], kind, object, fqn)
 	if err != nil {
 		ii.AddErr(ctx, err)
+		return
 	}
 	for _, e := range ee.Issues() {
-		ii.AddErr(ctx, errors.New(e))
+		ii.AddCode(ctx, 1503, e)
 	}
 }
 
-func jobResourceUsage(ctx context.Context, dba *db.DB, c Collector, jobs []*batchv1.Job) ConsumptionMetrics {
+func jobResourceUsage(dba *db.DB, jobs []*batchv1.Job) ConsumptionMetrics {
 	var mx ConsumptionMetrics
 
 	if len(jobs) == 0 {
