@@ -6,7 +6,7 @@ package report
 import (
 	"testing"
 
-	"github.com/derailed/popeye/pkg/config"
+	"github.com/derailed/popeye/internal/rules"
 
 	"github.com/stretchr/testify/assert"
 )
@@ -35,7 +35,7 @@ func TestChanged(t *testing.T) {
 		},
 	}
 
-	l := config.OkLevel
+	l := rules.OkLevel
 	for k := range uu {
 		u := uu[k]
 		t.Run(k, func(t *testing.T) {
@@ -77,7 +77,7 @@ func TestBetter(t *testing.T) {
 		},
 	}
 
-	l := config.OkLevel
+	l := rules.OkLevel
 	for k := range uu {
 		u := uu[k]
 		t.Run(k, func(t *testing.T) {
@@ -119,7 +119,7 @@ func TestWorst(t *testing.T) {
 		},
 	}
 
-	l := config.OkLevel
+	l := rules.OkLevel
 	for k := range uu {
 		u := uu[k]
 		t.Run(k, func(t *testing.T) {
@@ -164,7 +164,7 @@ func TestSummarize(t *testing.T) {
 		},
 	}
 
-	l := config.OkLevel
+	l := rules.OkLevel
 	for k := range uu {
 		u := uu[k]
 		t.Run(k, func(t *testing.T) {
